@@ -69,7 +69,7 @@ def define_auto(code):
         code = code.replace(" ","")
         if code.__contains__('getPlayer') or code.__contains__('sender'):
             type_Var = "Player"
-            m = 'public Player '+var_name+"= new Player();\n"
+            m = 'public Player '+var_name+";\n"
         elif code.__contains__('getWorld'):
             type_Var = "World"
             m = 'public World '+var_name+";\n"
@@ -791,6 +791,7 @@ def make(server,**setting):
                 code = code.replace("getLocation","getLocation()")
                 code = code.replace("getInventory","getInventory()")
                 code = code.replace("getBlock","getBlock()")
+                code = code.replace("getName","getName()")
                 code = code.replace("size","size()")
                 code = code.replace("Material","Type")
                 if code.__contains__("getX") or code.__contains__("getY") or code.__contains__("getZ"):
@@ -808,7 +809,7 @@ def make(server,**setting):
                     data = code.split("=")[1]
                     if data.__contains__('"'):
                         javacode = space.getspace(javacode)
-                        javacode += 'String '+var_name+";\n"
+                        javacode += 'String '+var_name+' = "";\n'
                     else:
                         javacode = space.getspace(javacode)
                         javacode += 'Integer '+var_name+";\n"
